<?php

namespace App\Http\Controllers;

use App\Models\Design;
use App\Models\PackagingListOrder;
use App\Models\Roll;
use Illuminate\Http\Request;

class RollController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return Roll::with('design', 'product', 'processing_house')->latest('created_at')->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
       if ($request->has('rolls')) {
        // dd($request->rolls);
    foreach ($request->rolls as $roll) {
        if (isset($roll['id'])) {
            Roll::updateOrCreate(['id' => $roll['id']], $roll);
        } else {
            Roll::create($roll);
        }
    }
}

return response(['msg' => 'success']);

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Roll  $rating
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        return Roll::where('id', $id)->with('design', 'product', 'processing_house')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Roll  $rating
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        return Roll::find($id)->update($request->all());
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Roll  $rating
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        return Roll::find($id)->delete();
    }
    
      public function splitAndCreateRoll(Request $request, $id)
    {
        // Retrieve the soft deleted roll
        $softDeletedRoll = Roll::withTrashed()->find($id);

        // Check if the soft deleted roll exists
        if (!$softDeletedRoll) {
            return response()->json(['error' => 'Soft deleted roll not found'], 404);
        }

        // Process incoming rolls
        if ($request->has('rolls')) {
            foreach ($request->rolls as $roll) {
                if (isset($roll['id'])) {
                    // Update existing roll or create a new one based on the ID
                    Roll::updateOrCreate(['id' => $roll['id']], $roll);
                } else {
                    // Create a new roll
                    Roll::create($roll);
                }
            }
        }

        // Optionally, you can add a response indicating success
        return response()->json(['message' => 'Rolls updated/created successfully']);
    }



    public function counts(Design $design)
    {
        $rollCounts = Roll::where('design_id', $design->id)->count();
        $processingCount = Roll::where('design_id', $design->id)->whereNotNull('processing_house_id')->count();
        $readyDispatchCount = Roll::where('design_id', $design->id)->where('is_ready_to_dispatch', 1)->count();

        $rolls = Roll::where('design_id', $design->id)->get();
        $packingRollsCount = 0;
        foreach ($rolls as $roll) {
            $packingRollsCount += PackagingListOrder::where('roll_id', $roll->id)->count();
        }

        return response()->json([
            'roll_count' => $rollCounts,
            'processingCount' => $processingCount,
            'readyDispatchCount' => $readyDispatchCount,
            'packingRollsCount' => $packingRollsCount,
        ]);
    }
}
